@@ -13,7 +13,8 @@ $scanner->add_scan_port(25);
 $scanner->add_scan_port(22);
 $scanner->add_scan_port(21);
 $scanner->ack_icmp_ping();
-$scanner->add_target($ARGV[0] || 'localhost');
+$scanner->add_target($ARGV[0] || 
+                         die "Missing host spec!\n$0 host_spec\n");
 $scanner->max_rtt_timeout(200);
 $scanner->register_port_found_event(\&found_port);
 $scanner->scan();
@@ -24,10 +25,10 @@ sub found_port {
     my $host = shift;
     my $port = shift;
 
-    my $name = $host->name();
-    my $ip   = join(',',map {$_->address()} $host->addresses());
+    my $name = $host->hostname();
+    my $ip   = join(',',map {$_->addr()} $host->addresses());
 
-    print "$name ($ip), port ",$port->number()," owned by ",
+    print "$name ($ip), port ",$port->portid()," owned by ",
           $port->owner(),"\n";
 
 }
