@@ -2,7 +2,7 @@ package Nmap::Scanner;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '0.5';
+$VERSION = '0.7';
 
 #  Set this to 1 and debugging is on for all modules
 $Nmap::Scanner::DEBUG = 0;
@@ -90,11 +90,11 @@ Nmap::Scanner - Perform and manipulate nmap scans using perl
       my $port     = shift;
   
       my $name = $host->name();
-      my $addresses = join(',', map {$_->address()} $host->addresses());
+      my $addresses = join(',', map {$_->addr()} $host->addresses());
   
       print "On host $name ($addresses), found ",
             $port->state()," port ",
-            join('/',$port->protocol(),$port->number()),"\n";
+            join('/',$port->protocol(),$port->portid()),"\n";
   
   }
 
