@@ -14,7 +14,7 @@ use strict;
 
 sub new {
     my $class = shift;
-    my $me = { FINISHED => undef, HOSTS => undef };
+    my $me = { FINISHED => '', HOSTS => '' };
     return bless $me, $class;
 }
 
@@ -42,10 +42,10 @@ sub as_xml {
 
     my $self = shift;
 
-    my $xml = "<run-stats";
-    $xml .= ' finished="' . $self->finished() . "\"/>\n";
-    $xml .= $self->hosts()->as_xml();
-    $xml .= "</run-stats>\n";
+    my $xml = "<runstats>";
+    $xml .= '<finished time="' . $self->finished() . "\" />\n";
+    $xml .= $self->hosts()->as_xml() if $self->hosts();
+    $xml .= "</runstats>\n";
 
     return $xml;
 
